@@ -5,35 +5,36 @@
 # @File    : __init__.py.py
 
 
+import logging
 import os
 
 import pip
 
 current = [
-    str(i.split(' ')[0])
-    for i in os.popen(f'pip list').readlines()
+    f'{i.split(" ")[0]}=={i.split(" ")[-1]}'.replace('\n', '')
+    for i in os.popen(f'pip list').readlines()[2:]
 ]
 
 
 def package(package_name: list):
     exist_lst = []
+    logging.info(current)
     for i in package_name:
         if i not in current:
+            logging.info(f'正在安装：{i}')
             pip.main(['install', i])
             exist_lst.append(i)
     return exist_lst
 
 
 pk_lst = [
-    'hashlib',
-    're',
-    'urllib',
-    'requests',
-    'faker',
-    'random',
-    'requests',
-    'scrapy',
-    'twisted',
-    'scrapy_redis'
+    'requests==2.27.1',
+    'Faker==13.2.0',
+    'Scrapy==2.5.1',
+    'scrapy-redis==0.7.2',
+    'Twisted==22.1.0',
+    'pymongo==3.6.0',
+    'pika==1.2.0',
+    'redis==4.1.4',
 ]
 package(pk_lst)
